pub struct SP1CudaProver { /* private fields */ }Expand description
A remote client to sp1_prover::SP1Prover that runs inside a container.
This is currently used to provide experimental support for GPU hardware acceleration.
WARNING: This is an experimental feature and may not work as expected.
Implementations
Sourceimpl SP1CudaProver
impl SP1CudaProver
Sourcepub fn new(moongate_server: MoongateServer) -> Result<Self, Box<dyn StdError>>
pub fn new(moongate_server: MoongateServer) -> Result<Self, Box<dyn StdError>>
Creates a new SP1CudaProver that can be used to communicate with the Moongate server at
moongate_endpoint, or if not provided, create one that runs inside a Docker container.
Sourcepub fn setup(
&self,
elf: &[u8],
) -> Result<(SP1ProvingKey, SP1VerifyingKey), Box<dyn StdError>>
pub fn setup( &self, elf: &[u8], ) -> Result<(SP1ProvingKey, SP1VerifyingKey), Box<dyn StdError>>
Executes the sp1_prover::SP1Prover::setup method inside the container.
Sourcepub fn prove_core(
&self,
stdin: &SP1Stdin,
) -> Result<SP1CoreProof, SP1CoreProverError>
pub fn prove_core( &self, stdin: &SP1Stdin, ) -> Result<SP1CoreProof, SP1CoreProverError>
Executes the sp1_prover::SP1Prover::prove_core method inside the container.
You will need at least 24GB of VRAM to run this method.
Sourcepub fn prove_core_stateless(
&self,
pk: &SP1ProvingKey,
stdin: &SP1Stdin,
) -> Result<SP1CoreProof, SP1CoreProverError>
pub fn prove_core_stateless( &self, pk: &SP1ProvingKey, stdin: &SP1Stdin, ) -> Result<SP1CoreProof, SP1CoreProverError>
Executes the sp1_prover::SP1Prover::prove_core method inside the container.
You will need at least 24GB of VRAM to run this method.
Sourcepub fn compress(
&self,
vk: &SP1VerifyingKey,
proof: SP1CoreProof,
deferred_proofs: Vec<SP1ReduceProof<InnerSC>>,
) -> Result<SP1ReduceProof<InnerSC>, SP1RecursionProverError>
pub fn compress( &self, vk: &SP1VerifyingKey, proof: SP1CoreProof, deferred_proofs: Vec<SP1ReduceProof<InnerSC>>, ) -> Result<SP1ReduceProof<InnerSC>, SP1RecursionProverError>
Executes the sp1_prover::SP1Prover::compress method inside the container.
You will need at least 24GB of VRAM to run this method.
Sourcepub fn shrink(
&self,
reduced_proof: SP1ReduceProof<InnerSC>,
) -> Result<SP1ReduceProof<InnerSC>, SP1RecursionProverError>
pub fn shrink( &self, reduced_proof: SP1ReduceProof<InnerSC>, ) -> Result<SP1ReduceProof<InnerSC>, SP1RecursionProverError>
Executes the sp1_prover::SP1Prover::shrink method inside the container.
You will need at least 24GB of VRAM to run this method.
Sourcepub fn wrap_bn254(
&self,
reduced_proof: SP1ReduceProof<InnerSC>,
) -> Result<SP1ReduceProof<OuterSC>, SP1RecursionProverError>
pub fn wrap_bn254( &self, reduced_proof: SP1ReduceProof<InnerSC>, ) -> Result<SP1ReduceProof<OuterSC>, SP1RecursionProverError>
Executes the sp1_prover::SP1Prover::wrap_bn254 method inside the container.
You will need at least 24GB of VRAM to run this method.